# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UdsOnCanTP.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10UdsOnCanTP.proto\x12\nUdsOnCanTP\x1a\x0c\x43ommon.proto\"R\n\tnode_info\x12\x17\n\x0frequest_id_phys\x18\x01 \x01(\x04\x12\x13\n\x0bresponse_id\x18\x02 \x01(\x04\x12\x17\n\x0frequest_id_func\x18\x03 \x01(\x04\"<\n\x0crequest_para\x12\x12\n\nseed_value\x18\x01 \x03(\r\x12\x18\n\x10\x61lgorithm_number\x18\x02 \x01(\r\"#\n\x0ekey_value_list\x12\x11\n\tkey_value\x18\x01 \x03(\r2\x8a\x01\n\nUdsOnCanTP\x12\x34\n\tsubscribe\x12\x15.UdsOnCanTP.node_info\x1a\x0e.Common.result\"\x00\x12\x46\n\x0cgenerate_key\x12\x18.UdsOnCanTP.request_para\x1a\x1a.UdsOnCanTP.key_value_list\"\x00\x62\x06proto3')



_NODE_INFO = DESCRIPTOR.message_types_by_name['node_info']
_REQUEST_PARA = DESCRIPTOR.message_types_by_name['request_para']
_KEY_VALUE_LIST = DESCRIPTOR.message_types_by_name['key_value_list']
node_info = _reflection.GeneratedProtocolMessageType('node_info', (_message.Message,), {
  'DESCRIPTOR' : _NODE_INFO,
  '__module__' : 'UdsOnCanTP_pb2'
  # @@protoc_insertion_point(class_scope:UdsOnCanTP.node_info)
  })
_sym_db.RegisterMessage(node_info)

request_para = _reflection.GeneratedProtocolMessageType('request_para', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST_PARA,
  '__module__' : 'UdsOnCanTP_pb2'
  # @@protoc_insertion_point(class_scope:UdsOnCanTP.request_para)
  })
_sym_db.RegisterMessage(request_para)

key_value_list = _reflection.GeneratedProtocolMessageType('key_value_list', (_message.Message,), {
  'DESCRIPTOR' : _KEY_VALUE_LIST,
  '__module__' : 'UdsOnCanTP_pb2'
  # @@protoc_insertion_point(class_scope:UdsOnCanTP.key_value_list)
  })
_sym_db.RegisterMessage(key_value_list)

_UDSONCANTP = DESCRIPTOR.services_by_name['UdsOnCanTP']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NODE_INFO._serialized_start=46
  _NODE_INFO._serialized_end=128
  _REQUEST_PARA._serialized_start=130
  _REQUEST_PARA._serialized_end=190
  _KEY_VALUE_LIST._serialized_start=192
  _KEY_VALUE_LIST._serialized_end=227
  _UDSONCANTP._serialized_start=230
  _UDSONCANTP._serialized_end=368
# @@protoc_insertion_point(module_scope)
