# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import Common_pb2 as Common__pb2
from . import ProcessNode_pb2 as ProcessNode__pb2


class ProcessNodeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetProcessInfo = channel.unary_unary(
                '/ProcessNode.ProcessNode/GetProcessInfo',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=ProcessNode__pb2.return_info.FromString,
                )
        self.GetVersionInfo = channel.unary_unary(
                '/ProcessNode.ProcessNode/GetVersionInfo',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=ProcessNode__pb2.return_info.FromString,
                )


class ProcessNodeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetProcessInfo(self, request, context):
        """复位 LinStackNode
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVersionInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProcessNodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetProcessInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProcessInfo,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=ProcessNode__pb2.return_info.SerializeToString,
            ),
            'GetVersionInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVersionInfo,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=ProcessNode__pb2.return_info.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ProcessNode.ProcessNode', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProcessNode(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetProcessInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ProcessNode.ProcessNode/GetProcessInfo',
            Common__pb2.empty.SerializeToString,
            ProcessNode__pb2.return_info.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVersionInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ProcessNode.ProcessNode/GetVersionInfo',
            Common__pb2.empty.SerializeToString,
            ProcessNode__pb2.return_info.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
