# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TcpIpNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fTcpIpNode.proto\x12\tTcpIpNode\x1a\x0c\x43ommon.proto\"6\n\x0fproto_port_info\x12\x11\n\tprotoName\x18\x01 \x01(\t\x12\x10\n\x08portList\x18\x02 \x03(\x04\"\x83\x01\n\x0fzone_ifcae_info\x12\x13\n\x0bnetworkName\x18\x01 \x01(\t\x12\x12\n\nswitchName\x18\x02 \x01(\t\x12\x12\n\nmacAddress\x18\x03 \x03(\x05\x12\x11\n\tipAddress\x18\x04 \x03(\x05\x12\x0f\n\x07netMask\x18\x05 \x03(\x05\x12\x0f\n\x07gateWay\x18\x06 \x03(\x05\"_\n\x10vector_port_info\x12\x13\n\x0bnetworkName\x18\x01 \x01(\t\x12\x12\n\nswitchName\x18\x02 \x01(\t\x12\x10\n\x08portName\x18\x03 \x01(\t\x12\x10\n\x08portType\x18\x04 \x01(\t\"e\n\x14vector_all_port_info\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12-\n\x08\x61ll_port\x18\x02 \x03(\x0b\x32\x1b.TcpIpNode.vector_port_info\"D\n\x0fopenPort_result\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x11\n\tportIndex\x18\x02 \x01(\x05\".\n\x0cgroupAddress\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0f\n\x07groupIp\x18\x02 \x03(\x05\x32\xc2\x05\n\tTcpIpNode\x12:\n\x0eInitTcpIpStack\x12\x16.Common.generic_string\x1a\x0e.Common.result\"\x00\x12\x32\n\x0fStartTcpIpStack\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12\x31\n\x0eStopTcpIpStack\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12H\n\x14GetAllVectorPortInfo\x12\r.Common.empty\x1a\x1f.TcpIpNode.vector_all_port_info\"\x00\x12K\n\x0eOpenVectorPort\x12\x1b.TcpIpNode.vector_port_info\x1a\x1a.TcpIpNode.openPort_result\"\x00\x12@\n\x10\x41\x64\x64ProtoPortInfo\x12\x1a.TcpIpNode.proto_port_info\x1a\x0e.Common.result\"\x00\x12J\n\x0e\x43reatZoneIface\x12\x1a.TcpIpNode.zone_ifcae_info\x1a\x1a.TcpIpNode.openPort_result\"\x00\x12\x34\n\x0bZoneIfaceUp\x12\x13.Common.generic_int\x1a\x0e.Common.result\"\x00\x12\x36\n\rZoneIfaceDown\x12\x13.Common.generic_int\x1a\x0e.Common.result\"\x00\x12\x38\n\x0fZoneIfaceRemove\x12\x13.Common.generic_int\x1a\x0e.Common.result\"\x00\x12\x45\n\x18ZoneIfaceAddGroupAddress\x12\x17.TcpIpNode.groupAddress\x1a\x0e.Common.result\"\x00\x62\x06proto3')



_PROTO_PORT_INFO = DESCRIPTOR.message_types_by_name['proto_port_info']
_ZONE_IFCAE_INFO = DESCRIPTOR.message_types_by_name['zone_ifcae_info']
_VECTOR_PORT_INFO = DESCRIPTOR.message_types_by_name['vector_port_info']
_VECTOR_ALL_PORT_INFO = DESCRIPTOR.message_types_by_name['vector_all_port_info']
_OPENPORT_RESULT = DESCRIPTOR.message_types_by_name['openPort_result']
_GROUPADDRESS = DESCRIPTOR.message_types_by_name['groupAddress']
proto_port_info = _reflection.GeneratedProtocolMessageType('proto_port_info', (_message.Message,), {
  'DESCRIPTOR' : _PROTO_PORT_INFO,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.proto_port_info)
  })
_sym_db.RegisterMessage(proto_port_info)

zone_ifcae_info = _reflection.GeneratedProtocolMessageType('zone_ifcae_info', (_message.Message,), {
  'DESCRIPTOR' : _ZONE_IFCAE_INFO,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.zone_ifcae_info)
  })
_sym_db.RegisterMessage(zone_ifcae_info)

vector_port_info = _reflection.GeneratedProtocolMessageType('vector_port_info', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR_PORT_INFO,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.vector_port_info)
  })
_sym_db.RegisterMessage(vector_port_info)

vector_all_port_info = _reflection.GeneratedProtocolMessageType('vector_all_port_info', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR_ALL_PORT_INFO,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.vector_all_port_info)
  })
_sym_db.RegisterMessage(vector_all_port_info)

openPort_result = _reflection.GeneratedProtocolMessageType('openPort_result', (_message.Message,), {
  'DESCRIPTOR' : _OPENPORT_RESULT,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.openPort_result)
  })
_sym_db.RegisterMessage(openPort_result)

groupAddress = _reflection.GeneratedProtocolMessageType('groupAddress', (_message.Message,), {
  'DESCRIPTOR' : _GROUPADDRESS,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.groupAddress)
  })
_sym_db.RegisterMessage(groupAddress)

_TCPIPNODE = DESCRIPTOR.services_by_name['TcpIpNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROTO_PORT_INFO._serialized_start=44
  _PROTO_PORT_INFO._serialized_end=98
  _ZONE_IFCAE_INFO._serialized_start=101
  _ZONE_IFCAE_INFO._serialized_end=232
  _VECTOR_PORT_INFO._serialized_start=234
  _VECTOR_PORT_INFO._serialized_end=329
  _VECTOR_ALL_PORT_INFO._serialized_start=331
  _VECTOR_ALL_PORT_INFO._serialized_end=432
  _OPENPORT_RESULT._serialized_start=434
  _OPENPORT_RESULT._serialized_end=502
  _GROUPADDRESS._serialized_start=504
  _GROUPADDRESS._serialized_end=550
  _TCPIPNODE._serialized_start=553
  _TCPIPNODE._serialized_end=1259
# @@protoc_insertion_point(module_scope)
